@@ -81,10 +81,9 @@ def dateTime_property(entity):
         if datetime_valid(date):
             return True
         else:
-            print("asdfd")
             return False
     except:
-        return "ssdfa"
+        return False
 
 def type_property(entity, type):
     try: 
@@ -275,7 +274,7 @@ def webbased_entity_check(tar_file, extension):
     
     NAME = "Web-based data entity check"
     error_message = {
-        "UrlError": "Semantic Error: Invalid ID at {}. It `should be a downloadable url",
+        "UrlError": "Semantic Error: Invalid ID at {}. It should be a downloadable url",
         "DateError": "Semantic Error: Invalid sdDatePublished {} or Not Provided",
         "TypeError": "Semantic Error: Invalid @type value of {}."
     }
@@ -399,7 +398,7 @@ def publisher_affiliation_correctness(item, entity, metadata, organization_resul
         if utils.get_norm_value(metadata[entity_property], "@type") == ["Organization"]:
             organization_result[utils.get_norm_value(entity, "@id")[0]] = True
         else:
-            organization_result[utils.get_norm_value(entity, "@id")[0]] = [False, error_message["OrganizationError"].format(item)]
+            organization_result[utils.get_norm_value(entity, "@id")[0]] = [False, error_message["OrganizationError"].format(utils.get_norm_value(metadata[entity_property], "@id"))]
         
 def organization_check(tar_file, extension):
     
@@ -449,7 +448,8 @@ def contact_info_check(tar_file, extension):
     
     NAME = "Contact information check"
     error_message = {
-        "TypeError": "Semantic Error: Invlaid Type Value at {}"
+        "TypeError": "Semantic Error: Invlaid Type Value at {}",
+        "ReferencingError":"Semantic Error: Invalid Referencing {} or Not Provided"
     }
     
     ###dictionary to store the checking result
@@ -479,7 +479,8 @@ def citation_check(tar_file, extension):
     NAME = "Citation property check"
     error_message = {
         "TypeError": "Semantic Error: Invalid Type Value at {}",
-        "IDError": "Semantic Error: Invalid ID Value at {}"
+        "IDError": "Semantic Error: Invalid ID Value at {}",
+        "ReferencingError":"Semantic Error: Invalid Referencing {} or Not Provided"
     }
     
     ### Dict to store the checking result
